declare class hyperJDB {
    private name;
    private path_database;
    private databasesObj;
    /**
     * @constructor Creates a database
     * @param {string} name The name of your database
     */
    constructor(name: string);
    /**
     * Sets a value into the database
     * @param {string} key JSON key to store data
     * @param {any} value The value to be stored
     * @returns {true}
     */
    set(key: string, value: any): true;
    /**
     * Gets an existing key from the database.
     * @param {string} key JSON key to be searched
     * @returns {any} The stored value
     */
    get(key: string): any;
    /**
     * Deletes an existing key from the database.
     * @param {string} key JSON key to search and delete
     * @returns {true}
     */
    delete(key: string): boolean;
    /**
     * Searches the given key.
     * @param {string} key The key to be searched
     * @returns {boolean} True if found, false if not
     */
    has(key: string): boolean;
    /**
     * Pushes to the given array a new value.
     * @param {string} key
     * @param {any} value
     * @returns The new array
     */
    push(key: string, value: any): any;
    /**
     * Adds to the given key the quantity provided
     * @param {string} key JSON key to be searched
     * @param {number} quantity Amount to be added
     * @returns {number} Updated value
     */
    add(key: string, quantity: number): number;
    /**
     * Substracts from the given key the quantity provided
     * @param {string} key JSON key to be searched
     * @param {number} quantity Amount to be substracted
     * @returns {number} Updated value
     */
    substract(key: string, quantity: number): number;
    /**
     * Clears **all** the data in the .json file
     * @returns {true}
     */
    drop(): true;
}
export = hyperJDB;
